@@ -2,7 +2,7 @@
 #while [$? -eq 0]]; do
 #  ++c
 #  echo Running attempt $c
-#  mvn clean install -pl core -Dts.manualmode=true -Dtest=RapidResetDDoSUnitTestCase
+#  mvn clean install -pl testsuite/integration/manualmode -Dts.manualmode=true -Dtest=ReplicatedFailoverTestCase#testBackupActivation
 #  if [$? -eq  0]; then
 #      break;
 #  fi
@@ -14,7 +14,7 @@ while
       i=`expr $i + 1`
       #: ${start=$i}              # capture the starting value of i
       ## some other commands      # needed for the loop
-      mvn clean install -pl core  -Dtest=RapidResetDDoSUnitTestCase
+      mvn clean install -pl testsuite/integration/manualmode -Dts.manualmode=true -Dtest=ReplicatedFailoverTestCase#testBackupActivation
 #testBackupFailoverAfterFailback
 #testBackupActivation
       (($? == 0 ))             # Place the loop ending test here.
